EffectsPreset class

A snapshot of all active DSP effect settings, for save/restore.

Constructors

EffectsPreset({required EqSettings eq, required ReverbPreset reverb, required double reverbWetMix, required CompressorSettings compressor, CutoffFilterSettings? cutoff})
const

Properties

compressor CompressorSettings
final
cutoff CutoffFilterSettings?
final
eq EqSettings
final
hashCode int
The hash code for this object.
no setterinherited
reverb ReverbPreset
final
reverbWetMix double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited