saveLoopPointB method
Saves the current playback position as loop point B.
Implementation
Future<void> saveLoopPointB() async {
_checkNotDisposed();
_loopPointB = await currentPosition;
}
Saves the current playback position as loop point B.
Future<void> saveLoopPointB() async {
_checkNotDisposed();
_loopPointB = await currentPosition;
}